diff include/Utilities.h @ 303:421a69d42943 prerelease

Changed BeagleRT -> Bela in defines and thread names; some preliminary mux capelet stuff
author andrewm
date Fri, 27 May 2016 17:40:44 +0100
parents e4392164b458
children 1feb9c23ac57
line wrap: on
line diff
--- a/include/Utilities.h	Fri May 27 17:28:24 2016 +0100
+++ b/include/Utilities.h	Fri May 27 17:40:44 2016 +0100
@@ -123,7 +123,7 @@
  * This function sets the value of an analog output, at the time indicated by \c frame. Valid
  * values are between 0 and 1, corresponding to the range 0 to 5V.
  *
  * The value written will persist for all future frames if BEAGLERT_FLAG_ANALOG_OUTPUTS_PERSIST
  * is set in context->flags. This is the default behaviour.
  *
  * \param context The I/O data structure which is passed by Bela to render().
@@ -144,7 +144,7 @@
  * Unlike analogWriteFrame(), the value written will affect \b only the frame specified, with
  * future values unchanged. This is faster than analogWriteFrame() so is better suited
  * to applications where every frame will be written to a different value. If
  * BEAGLERT_FLAG_ANALOG_OUTPUTS_PERSIST is not set within context->flags, then
  * analogWriteFrameOnce() and analogWriteFrame() are equivalent.
  *
  * \param context The I/O data structure which is passed by Bela to render().
@@ -358,7 +358,7 @@
 // Sets a given analog output channel to a value for the current frame and, if persistent outputs are
 // enabled, for all subsequent frames
 static inline void analogWriteFrame(BelaContext *context, int frame, int channel, float value) {
-	if(context->flags & BEAGLERT_FLAG_ANALOG_OUTPUTS_PERSIST) {
+	if(context->flags & BELA_FLAG_ANALOG_OUTPUTS_PERSIST) {
 		for(unsigned int f = frame; f < context->analogFrames; f++)
 			context->analogOut[frame * context->analogChannels + channel] = value;
 	}
@@ -123,7 +123,7 @@
  * values are between 0 and 1, corresponding to the range 0 to 5V.
  *
- * The value written will persist for all future frames if BEAGLERT_FLAG_ANALOG_OUTPUTS_PERSIST
+ * The value written will persist for all future frames if BELA_FLAG_ANALOG_OUTPUTS_PERSIST
  * is set in context->flags. This is the default behaviour.
  *
@@ -144,7 +144,7 @@
  * future values unchanged. This is faster than analogWriteFrame() so is better suited
  * to applications where every frame will be written to a different value. If
- * BEAGLERT_FLAG_ANALOG_OUTPUTS_PERSIST is not set within context->flags, then
+ * BELA_FLAG_ANALOG_OUTPUTS_PERSIST is not set within context->flags, then
  * analogWriteFrameOnce() and analogWriteFrame() are equivalent.
  *